# AutoNetkit

AutoNetkit is a configuration engine to quickly and easily build large-scale network configurations.

[comment]: <> ([![PyPi version]&#40;https://pypip.in/v/autonetkit/badge.png&#41;]&#40;https://crate.io/packages/autonetkit/&#41;)

Update: the code has been rewritten for Python3 compatibility. This is a ground-up rewrite for performance and ease of use, with a cleaner API and many of the complexities and quirks of the previous research-based code removed.
This update is being finalised and is in the process of being tested and pushed to PyPi.

The code is usable, and can be used for end-to-end configuration generation.

For an example of using the API, please see the tutorial, and for an end-to-end use-case please see the tests, in particular test_core which will build a series of configurations from the provided example .graphml topology.

# Features

## High-level syntax

## Visualization

## Visualization

## Extending

# Users

Users from industry, academia, and university teaching.

# Further information

More information on AutoNetkit:

* [AutoNetkit YouTube Channel](http://www.youtube.com/autonetkit)
* [CoNEXT 2013 Slides](https://db.tt/JkRrU5q5) (Dec 13)
* [CoNext 2013 Conference Paper](http://conferences.sigcomm.org/co-next/2013/program/p235.pdf)
* [Extended recording of CoNext Slides](https://www.youtube.com/watch?v=0W73HLdlwOs)
* [PyCon Australia 2013 Presentation on Autonetkit](http://t.co/H4NWROoAJK) [(Slides)](http://t.co/x0NXLMATEq) (July 13)

* [API Documentation](https://autonetkit.readthedocs.org/)
* [AutoNetkit website](http://www.autonetkit.org)

# Contact

* [Twitter](https://twitter.com/autonetkit)
* [Mailing list](https://groups.google.com/group/autonetkit)

